/* palomaWindow.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "palomaWindow.h"

#include "icon.xpm"

Gdk_Pixmap PalomaWindow::_icon_gdk_pixmap;
Gdk_Bitmap PalomaWindow::_icon_gdk_mask;
bool PalomaWindow::_got_pixmaps = false;

PalomaWindow::
PalomaWindow() {
  _destroyed = false;
}

PalomaWindow::
~PalomaWindow() {
  // We must hide the window before we destruct, or it won't disappear
  // from the screen.  Strange.  But we also don't want to try to hide
  // the window if we're destructing because of a window_destroyed
  // event, so we check our little flag.
  if (!_destroyed) {
    hide();
  }
}

void PalomaWindow::
setup() {
  connect_to_method(destroy, this, &window_destroyed);
  show();
  setup_icon_for_window(this, _icon_pixmap, _icon_window);
}


// Call this function to make the dove image be an icon for any window
// after it is created.  You need to have a Gtk_Pixmap and a
// Gtk_Window object ready.  PalomaDialog does this automatically.
void PalomaWindow::
setup_icon_for_window(Gtk_Window *window, Gtk_Pixmap &icon_pixmap, 
		      Gtk_Window &icon_window) {
  Gdk_Window gdk_window = window->get_window();

  if (!_got_pixmaps) {
    _icon_gdk_pixmap.create_from_xpm_d
      (gdk_window, _icon_gdk_mask, (GdkColor *)NULL, icon_xpm);
    
    _got_pixmaps = true;
  }

  icon_pixmap.set(_icon_gdk_pixmap, _icon_gdk_mask);
  icon_window.add(icon_pixmap);
  icon_pixmap.show();
  Gdk_Window icon_gdk_window = icon_window.get_window();
  gdk_window.set_icon(icon_gdk_window,
		      _icon_gdk_pixmap, _icon_gdk_mask);
}

void PalomaWindow::
window_destroyed() {
  _destroyed = true;
  delete_self();
}
